clear all

*********************** SETUP AND MERGE ******************************

*--------------------------------------------
/* Holger Döring and Philip Manow, the creators of the ParlGov data, voiced the 
preference that we do not upload the raw ParlGov data as part of this replication
package. Therefore, the following code that creates the baseline dataset from the 
raw data is commented out, and the replication package uses a saved version of 
the baseline data created with this code ("partygovdata.dta"). To perfectly 
replicate the project, save the three sub-datasets of ParlGov (election, cabinet, 
party) in Stata format into the "data/raw" folder and run the following code. 
*--------------------------------------------

// prepare next elections data 
local list vote_share edate
use "data/raw/parlgov_election.dta", clear
drop if election_type=="ep"
gen edate = date(election_date, "YMD")
format %td edate
sort party_id edate
rename election_id next_election_id 
rename previous_parliament_election_id election_id
foreach var in `list' {
	rename `var' next_`var'
}
keep party_id election_id next_*
drop if mi(election_id) | mi(next_election_id)
tempfile nextmerge 
save `nextmerge', replace

use "data/raw/parlgov_election.dta", clear
foreach num of numlist 1/3 {
	merge m:1 party_id election_id using `nextmerge', nogen keep(1 3)
	local numminus = `num'-1
	rename election_id election_id_t`numminus' 
	rename next_election_id election_id 
	foreach var in `list' {
		rename next_`var' `var'_t`num'
	}
}
rename election_id election_id_t3
rename election_id_t0 election_id
local keeplist
foreach var in `list' {
	local keeplist "`keeplist' `var'*"
}
keep party_id election_id `keeplist'
save "data/processed/parlgov_election_next.dta", replace

// load and prepare cabinet data
use "data/raw/parlgov_cabinet.dta", clear
kountry country_name, from(other) stuck
rename _ISO3N_ iso
gen startdate = date(start_date, "YMD")
format %td startdate
gen edate = date(election_date, "YMD")
format %td edate
sort country_id edate startdate party_id
by country_id: gen enddate1 = (startdate[_n+1]-1) if startdate[_n+1]!=startdate
egen enddate = max(enddate1), by(country_id cabinet_id)
format %td enddate

// crucial variable generation before collapsing the data
*help variables
gen seatshare = cond(!mi(seats) & !mi(election_seats_total),seats/election_seats_total,0)
gegen govseats = sum(seatshare) if cabinet_party==1, by(iso cabinet_id)
gen seatshare_ingov = seatshare/govseats
merge m:1 party_id using "data/raw/parlgov_party.dta", nogen keepus(family_id) keep(1 3)
gen left = cond(inlist(family_id,19,11,14),1,0)
*minority gov
gen minority = cond(!mi(govseats) & govseats<.5,1,0) if cabinet_party==1
*effective no of parties
gegen maxseatshare = max(seatshare) if seatshare>0 & !mi(seatshare), by(iso cabinet_id)
gen effnum = 1/(1+((maxseatshare*maxseatshare)/seatshare)-seatshare)
gegen effnum_party = sum(effnum) if seatshare>0 & !mi(seatshare), by(iso cabinet_id)
*government cohesion
gegen helpcohesion = max(seatshare_ingov) if cabinet_party==1 & !mi(seatshare_ingov), by(iso cabinet_id)
gen dominantparty = 1 if seatshare_ingov==helpcohesion & cabinet_party==1
gen dominantpartyfam = left if dominantparty==1 & cabinet_party==1
gegen dominantpartycode = max(dominantpartyfam) if cabinet_party==1, by(iso cabinet_id)
replace dominantpartycode = . if dominantpartycode!=left
gegen ideo_cohesion_help = sum(seatshare_ingov) if !mi(dominantpartycode) & cabinet_party==1, by(iso cabinet_id dominantpartycode)
gegen ideo_cohesion = max(ideo_cohesion_help) if cabinet_party==1, by(iso cabinet_id)
*dominant party seat share
gen headshare_help = seatshare_ingov if dominantparty==1 & cabinet_party==1
gegen headshare = max(headshare_help) if cabinet_party==1, by(iso cabinet_id)
*cohabitation
gen cohabitation = 0 if cabinet_party==1
foreach x in "Klaus III" "Vranitzky I" "Silva I" "Silva II" "Silva III" "Passos Coelho I" "Passos Coelho II" ///
"Chirac II" "Balladur" "Jospin" "Tusk I" "Tusk II" "Schuessel IV" "Aho I" "Aho II" "Vanhanen II" ///
"Cosgrave L" "Fitzgerald I" "Fitzgerald II" "Haughey IV" "Reynolds I" "Kenny II" "Barroso" {
	replace cohabitation = 1 if cabinet_name=="`x'" & cabinet_party==1
}

// create baseline dataset of party-governments
keep if cabinet_party==1 & caretaker!=1 & !mi(startdate) & !mi(enddate)
collapse (min) startdate edate (max) enddate minority effnum_party cohabitation ideo_cohesion headshare (first) country_name seats election_seats_total party_name_short party_name party_name_english , by(iso election_id party_id)
sort iso startdate party_id 

// merge ParlGov datasets
merge m:1 party_id using "data/raw/parlgov_party.dta", nogen keepus(family_name family_id state_market cmp) keep(1 3)
merge 1:1 party_id election_id using "data/processed/parlgov_election_next.dta", nogen keep(1 3)

// saved edited version
save "data/raw/partygovdata.dta", replace

*/

// load the baseline dataset
use "data/raw/partygovdata.dta", clear

// merge further data
merge m:1 iso using "data/processed/cwed_processed.dta", keep(1 3) nogen
merge m:1 iso using "data/processed/reformevent_processed.dta", keep(1 3) nogen
merge m:1 iso using "data/processed/cpds_processed.dta", keep(1 3) nogen 

// clean 
sort iso startdate party_name_english 


*********************** PARTY AND GOVERNMENT VARIABLES ******************************

// start and end dates of governments
replace enddate = edate_t1 if edate_t1<enddate
gen startyear = year(startdate)
gen endyear = year(enddate)
gen totyears = endyear-startyear 
gen days = enddate-startdate
gen logdays = log(days)
foreach d in start end {
    foreach t in year month day {
		gen `d'_`t' = `t'(`d'date)
	}
	gen `d'date_ym = (`d'_year*12)+(`d'_month)
	drop `d'_year `d'_month `d'_day
}

// vote change
gen votechange = vote_share_t1-vote_share
gen votechange_pc = ((vote_share_t1-vote_share)/vote_share)*100
gen votechange_long = ((vote_share_t2-vote_share)+(vote_share_t3-vote_share))/2
gen votechange_long_pc = (((vote_share_t2-vote_share)/vote_share)+((vote_share_t3-vote_share)/vote_share))/2

// number of cabinet parties
bys iso startdate: egen no_cabparties1 = count(days)
bys iso startdate party_id: egen no_cabparties = mean(no_cabparties1)  // this should be weighted by days, but not needed for our purpose
gen singlepartygov = cond(no_cabparties==1 & minority!=1,1,0) if !mi(no_cabparties)
gen dualpartygov = cond(inrange(no_cabparties,1,2),1,0) if !mi(no_cabparties)
drop no_cabparties1

// party family variables
gen parfam = .
replace parfam = 1 if family_id==19 
replace parfam = 2 if family_id==11 | family_id==14
replace parfam = 3 if family_id==6
replace parfam = 4 if family_id==3
replace parfam = 5 if family_id==26 | family_id==40
replace parfam = 6 if family_id==2
replace parfam = 7 if family_id==12
replace parfam = 99 if family_id==16
lab def partyfam 1 "Ecologist" 2 "Social dem. & socialist" 3 "Liberal" ///
	4 "Christian democrat" 5 "Conservative & right-wing" 6 "Agrarian" ///
	7 "Other" 99 "Special issue"
lab val parfam partyfam
recode parfam (1 2=1) (3 4 5 6 7 99=0), gen(left)
recode parfam (1 2 4=1) (3 5 6 7 99=0), gen(left_alt)
recode parfam (1 2=1) (3 5=0) (4 6 7 99=.), gen(left_vs_right)
drop family_name family_id

// young democracy identifier
gen youngdem = inlist(country,"Spain","Portugal","Greece")


*********************** POLICY CHANGE AND REFORM EVENT VARIABLES  ******************************

// entitlement, social spending, and economic condition changes
sort iso startdate party_id
qui sum totyears
local maxtotyear = r(max)
foreach y in 	uegen uegen_vis pengen pengen_vis ///
				unemp realgdpgr socspend debt deficit {
	local `y'list
	foreach govy of numlist 1/`maxtotyear' {
		gen `y'`govy' = .
		local `y'list ``y'list' `y'`govy'
	}
	foreach i of numlist 1960/2020 {
		foreach govy of numlist 1/`maxtotyear' {
			local n = `govy'-1
			cap replace `y'`govy' = `y'`i' if `i'==(startyear+`n') & endyear>=(startyear+`n') & !mi(endyear)
		}
	}
	gen D`y' = .
	gen D`y'_short = .
	foreach govy of numlist 2/`maxtotyear' {
		local n = `govy'-1
		replace D`y' = `y'`govy'-`y'1 if totyears==`n'
		replace D`y'_short = `y'`govy'-`y'`n' if totyears==`n'
	}
	egen `y'_avg = rowmean(``y'list')
	clonevar `y'_y1 = `y'1
	drop ``y'list'
}

// welfare reform events
foreach x in Rue_retrench Rue_expand Rpen_retrench Rpen_expand Rue_visretrench ///
Rue_visexpand Rpen_visretrench Rpen_visexpand {
    gen `x' = 0 if (	(iso==208 & startyear>=1972 & endyear<=2014) | ///
						(iso==246 & startyear>=1972 & endyear<=2014) | ///
						(iso==250 & startyear>=1974 & endyear<=2014) | ///
						(iso==276 & startyear>=1974 & endyear<=2014) | ///
						(iso==826 & startyear>=1946 & endyear<=2016) )
	foreach year of numlist 1946/2017 {
		foreach month of numlist 1/12 {
			local comb = (`year'*12)+`month'
			cap replace `x' = `x'+`x'`comb' if !mi(`x'`comb') & `comb'>=startdate_ym & `comb'<=enddate_ym
		}
	}
}
foreach x in ue pen {
	gen R`x'gen = R`x'_expand-R`x'_retrench 
	gen R`x'gen_vis = R`x'_visexpand-R`x'_visretrench 

	rename R`x'_expand R`x'gen_exp
	rename R`x'_retrench  R`x'gen_retr
	
	rename R`x'_visexpand R`x'gen_vis_exp
	rename R`x'_visretrench  R`x'gen_vis_retr
}

foreach x in Rue_retrench Rue_expand Rpen_retrench Rpen_expand {
    gen `x' = 0 if (	(iso==208 & startyear>=1972 & endyear<=2014) | ///
						(iso==246 & startyear>=1972 & endyear<=2014) | ///
						(iso==250 & startyear>=1974 & endyear<=2014) | ///
						(iso==276 & startyear>=1974 & endyear<=2014) | ///
						(iso==826 & startyear>=1946 & endyear<=2016) )
	foreach year of numlist 1946/2017 {
		foreach month of numlist 1/12 {
			local comb = (`year'*12)+`month'
			local comb_year = ((`year'*12)+`month')+12
			cap replace `x' = `x'+`x'`comb' if !mi(`x'`comb') & `comb'>=startdate_ym & `comb'<=enddate_ym  & `comb_year'>=enddate_ym
		}
	}
}

foreach x in ue pen {
	gen R`x'gen_short = R`x'_expand-R`x'_retrench 

	rename R`x'_expand R`x'gen_short_exp
	rename R`x'_retrench  R`x'gen_short_retr
}

// drop all unneeded variables
drop uegen1970-socspend2019
cap drop *shortvis* *visshort*


*********************** RESTRICT SAMPLE ******************************

sort iso startdate party_id
keep if startyear>=1970 & days>=365 & !mi(days) & parfam!=99 & vote_share>0 & !mi(vote_share) & !mi(votechange_pc) & ///
	(!mi(Duegen) | !mi(Dpengen) | !mi(Dsocspend) | !mi(Ruegen)  | !mi(Rpengen))
gen keep3 = 1
foreach x in Dunemp unemp_avg Drealgdpgr realgdpgr_avg deficit_y1 {
    replace keep3 = 0 if mi(`x')
}
egen keep = max(Duegen), by(iso)
egen keep2 = max(Dpengen), by(iso)
drop if (mi(keep) & mi(keep2)) | keep3!=1
drop keep keep2 keep3


*********************** OUTLIER VALUES  ******************************

// copy version before excluding outliers
foreach x in votechange_pc Duegen {
    clonevar `x'_ol = `x'
}

replace votechange_pc = . if votechange_pc>100
replace Duegen = . if Duegen>5


*********************** FINALIZE VARIABLES AND DATASET  ******************************

// clarity of responsibility variables
foreach x in ideo_cohesion headshare {
	qui sum `x'
	replace `x' = (`x'-r(min))*1/(r(max)-r(min))
}
gen clarity = (ideo_cohesion+headshare+singlepartygov+cohabitation)/4
qui sum clarity,d 
gen clarity_dum = clarity>=r(p50) & !mi(clarity)
drop ideo_cohesion headshare singlepartygov cohabitation dualpartygov

// fiscal pressure identifier
gen high_pressure = cond(deficit_y1<-3,1,0) if !mi(deficit_y1)
gen low_pressure = cond(deficit_y1>=0,1,0) if !mi(deficit_y1)

// retrenchment vs expansion
foreach x in 	Duegen Duegen_vis Duegen_short ///
				Dpengen Dpengen_vis Dpengen_short ///
				Dsocspend Dsocspend_short {
	gen `x'_retr = cond(`x'<=0,abs(`x'),0) if !mi(`x')
	gen `x'_exp = cond(`x'>=0,abs(`x'),0) if !mi(`x')
}

// rescale variables
foreach x in Duegen Dpengen Ruegen Rpengen Dsocspend {
	cap sum `x'`variant'
	cap replace `x'`variant' = `x'`variant'/r(sd)
	foreach version in _retr _exp {
		cap sum `x'`version'
		cap replace `x'`version' = `x'`version'/r(sd)
	}
	foreach variant in _vis _short {
		cap sum `x'`variant'
		cap replace `x'`variant' = `x'`variant'/r(sd)
		foreach version in _retr _exp {
			cap sum `x'`variant'`version'
			cap replace `x'`variant'`version' = `x'`variant'`version'/r(sd)
		}
	}
}

// label all important variables
lab var votechange "Vote change (pp.)"
lab var votechange_pc "Vote change (%)"

lab var Duegen "UB generosity change"
lab var Duegen_retr "UB generosity retrenchment"
lab var Duegen_exp "UB generosity expansion"
lab var Duegen_vis "Visible UB generosity change"
lab var Duegen_vis_retr "Visible UB generosity retrenchment"
lab var Duegen_vis_exp "Visible UB generosity expansion"
lab var Duegen_short "Short-term UB generosity change"
lab var Duegen_short_retr "Short-term UB generosity retrenchment"
lab var Duegen_short_exp "Short-term UB generosity expansion"

lab var Dpengen "Pension generosity change"
lab var Dpengen_retr "Pension generosity retrenchment"
lab var Dpengen_exp "Pension generosity expansion"
lab var Dpengen_vis "Visible pension generosity change"
lab var Dpengen_vis_retr "Visible pension generosity retrenchment"
lab var Dpengen_vis_exp "Visible pension generosity expansion"
lab var Dpengen_short "Short-term pension generosity change"
lab var Dpengen_short_retr "Short-term pension generosity retrenchment"
lab var Dpengen_short_exp "Short-term pension generosity expansion"

lab var Dsocspend "Social spending change"
lab var Dsocspend_exp "Social spending expansion"
lab var Dsocspend_retr "Social spending retrenchment"
lab var Dsocspend_short "Short-term social spending change"
lab var Dsocspend_short_retr "Short-term social spending retrenchment"
lab var Dsocspend_short_exp "Short-term social spending expansion"

lab var Ruegen "UB reform"
lab var Ruegen_retr "UB retrenchment reform"
lab var Ruegen_exp "UB expansion reform"
lab var Ruegen_vis "Visible UB reform"
lab var Ruegen_vis_retr "Visible UB retrenchment reform"
lab var Ruegen_vis_exp "Visible UB expansion reform"
lab var Ruegen_short "Short-term UB reform"
lab var Ruegen_short_retr "Short-term UB retrenchment reform"
lab var Ruegen_short_exp "Short-term UB expansion reform"

lab var Rpengen "Pension reform"
lab var Rpengen_retr "Pension retrenchment reform"
lab var Rpengen_exp "Pension expansion reform"
lab var Rpengen_vis "Visible pension reform"
lab var Rpengen_vis_retr "Visible pension retrenchment reform"
lab var Rpengen_vis_exp "Visible pension expansion reform"
lab var Rpengen_short "Short-term pension reform"
lab var Rpengen_short_retr "Short-term pension retrenchment reform"
lab var Rpengen_short_exp "Short-term pension expansion reform"

lab var Dunemp "Unemployment change"
lab var unemp_avg "Average unemployment"
lab var Drealgdpgr "GDP growth change"
lab var realgdpgr_avg "Average GDP growth"
lab var deficit_y1 "Initial household balance"
lab var effnum_party "Effective number of parties"
lab var logdays "Government duration (log days)"
lab var days "Government duration in days"
lab var vote_share "Initial vote share"
lab var left "Pro-welfare party"
lab var left_alt "Pro-welfare party (including CDs)"
lab var left_vs_right "Left party vs. right party"
lab var clarity_dum "High clarity of responsibility"
lab var low_pressure "Low fiscal pressure"
lab var high_pressure "High fiscal pressure"

// final dataset sort and count
egen gov_id = group(iso edate)
egen partycount = tag(party_id)
egen electioncount = tag(iso edate)
egen countrycount = tag(iso)
qui count
dis r(N) " observations overall"
qui count if partycount==1
dis "from " r(N) " parties"
qui count if electioncount==1
dis "from " r(N) " governments"
qui count if countrycount==1
dis "from " r(N) " countries"
drop partycount electioncount countrycount
sort iso party_id startdate 

// time identifier variable
gen time_fe = irecode(endyear,1970,1979,1989,1999,2009,2019)
tab time_fe, gen(time_fe)


*********************** SAVE CLEAN DATA ******************************

save "data/processed/finaldata.dta", replace


